from loguru import logger

model_cost_query = {
    "gpt-4o": 5 / 1000000,
    "gpt-4o-2024-08-06": 2.5 / 1000000,
    "gpt-4o-mini": 0.15 / 1000000,
    "gpt-3.5-turbo": 0.5 / 1000000
}
model_cost_output = {
    "gpt-4o": 15 / 1000000,
    "gpt-4o-2024-08-06": 10 / 1000000,
    "gpt-4o-mini": 0.6 / 1000000,
    "gpt-3.5-turbo": 1.5 / 1000000
}
model_cost_image = {
    "normal": 0.04,
    "high": 0.08,
}


def get_cost(response, model):
    response_message = response.choices[0].message
    completion_tokens = response.usage.completion_tokens
    prompt_tokens = response.usage.prompt_tokens
    try:
        cost = model_cost_query[model] * prompt_tokens + model_cost_output[model] * completion_tokens
    except Exception as e:
        logger.error(f"Error calculating cost for model {model}: {e}")
        cost = None

    return cost
