from typing import List, Type

import sys
from pathlib import Path

from loguru import logger
from pydantic import BaseModel
from tqdm import tqdm
from wuenlp.impl.UIMANLPStructs import UIMADocument, UIMAAnnotation, UIMASystemScene

from wuenlp_tools.utils.prompting import LLM, gpt4omini


class Summary(BaseModel):
    summary: str
    keywords: List[str]


sentences = 3
summariser = LLM(model=gpt4omini,
                 system_prompt=f"You are given a text corresponding to a scene in a text. Please summarize the scene in about {sentences} sentences and provide 1-3 keywords that will help a reader familiar with the text to recognise the scene.",
                 output_format=Summary)

logger.remove()
logger.add(sys.stdout, level="INFO")


def summarize_doc(doc: UIMADocument, serialize=0, segment_type: Type[UIMAAnnotation] = UIMASystemScene) -> UIMADocument:
    segments = doc.system_scenes if segment_type == UIMASystemScene else doc._get_annos_of_type(segment_type)
    for i, segment in tqdm(enumerate(segments)):
        if "llama_summary" in segment.additional_features:
            continue
        scene_text = segment.text
        summary: Summary = summariser(scene_text)
        segment.additional_features["llama_summary"] = summary.summary
        segment.additional_features["llama_keywords"] = summary.keywords
        logger.info(summary)
        if serialize and i % serialize == 0:
            doc.serialize(doc.path)
    return doc


def summarize_scenes(xmi: Path):
    doc = UIMADocument.from_xmi(xmi)
    doc = summarize_doc(doc, serialize=10)
    doc.serialize(xmi)
